package com.zhentao.util;

import javax.crypto.Cipher;
import javax.crypto.spec.IvParameterSpec;
import javax.crypto.spec.SecretKeySpec;
import java.nio.charset.StandardCharsets;
import java.util.Base64;

public class WXBizDataCryptUtil {

    /**
     * 解密微信小程序加密数据
     * @param appId 小程序的 appId
     * @param sessionKey 微信返回的 session_key
     * @param encryptedData 加密数据
     * @param iv 初始向量
     * @return 解密后的数据，如果解密失败返回 null
     */
    public static String decryptData(String appId, String sessionKey, String encryptedData, String iv) {
        try {
            // 对 session_key 进行 Base64 解码
            byte[] sessionKeyBytes = Base64.getDecoder().decode(sessionKey);
            // 对 encryptedData 进行 Base64 解码
            byte[] encryptedDataBytes = Base64.getDecoder().decode(encryptedData);
            // 对 iv 进行 Base64 解码
            byte[] ivBytes = Base64.getDecoder().decode(iv);

            // 创建 AES 密钥规范
            SecretKeySpec secretKeySpec = new SecretKeySpec(sessionKeyBytes, "AES");
            // 创建 AES 加密算法的初始向量规范
            IvParameterSpec ivParameterSpec = new IvParameterSpec(ivBytes);

            // 创建 Cipher 对象，使用 AES/CBC/PKCS7Padding 算法
            Cipher cipher = Cipher.getInstance("AES/CBC/PKCS7Padding");
            // 初始化 Cipher 对象为解密模式
            cipher.init(Cipher.DECRYPT_MODE, secretKeySpec, ivParameterSpec);

            // 进行解密操作
            byte[] decryptedBytes = cipher.doFinal(encryptedDataBytes);
            // 将解密后的字节数组转换为字符串
            return new String(decryptedBytes, StandardCharsets.UTF_8);
        } catch (Exception e) {
            e.printStackTrace();
            return null;
        }
    }
}    